@@ -1,10 +1,11 @@
 from __future__ import annotations
 
 import bz2
+import logging
 from pathlib import Path
 from shutil import get_unpack_formats, register_unpack_format
 
-from .utils import Log
+logger = logging.getLogger(__name__)
 
 
 def _unpack_bz2(filename, extract_dir):
@@ -20,10 +21,10 @@ def _unpack_bz2(filename, extract_dir):
 
 def register_unpack_formats():
     """Register custom unpack formats."""
-    Log.debug("Registering custom unpack formats.")
+    logger.debug("Registering custom unpack formats.")
 
     formats = get_unpack_formats()
     if "bz2" not in map(lambda x: x[0], formats):
         register_unpack_format("bz2", [".bz2"], _unpack_bz2, description="bz2 files")
 
-    Log.debug(f"Unpack formats available: {formats}")
+    logger.debug(f"Unpack formats available: {formats}")
